@@ -7,6 +7,9 @@ from mainnet.api.contract_api import ContractApi
 from mainnet.api.contract_escrow_api import ContractEscrowApi
 from mainnet.api.faucet_api import FaucetApi
 from mainnet.api.mine_api import MineApi
+from mainnet.api.smartbch_contract_api import SmartbchContractApi
+from mainnet.api.smartbch_sep20_api import SmartbchSep20Api
+from mainnet.api.smartbch_wallet_api import SmartbchWalletApi
 from mainnet.api.util_api import UtilApi
 from mainnet.api.wallet_api import WalletApi
 from mainnet.api.wallet_slp_api import WalletSlpApi
